//
//  AppDelegate.m
//  AUDataLoadersExample
//
//  Created by Emil Wojtaszek on 21.07.2012.
//  Copyright (c) 2012 __MyCompanyName__. All rights reserved.
//

#import "AppDelegate.h"

#import "LocalViewController.h"
#import "RemoteViewController.h"

@implementation AppDelegate

@synthesize window = _window;
@synthesize tabBarController = _tabBarController;

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    // Initialize RestKit
    NSURL* url = [NSURL URLWithString:@"http://demo.report100.com/api"];
    RKObjectManager* objectManager = [RKObjectManager objectManagerWithBaseURL:url];
    [objectManager setClient:[RKClient sharedClient]];
    
    // Initialize object store
    NSString *seedDatabaseName = nil;
    NSString *databaseName = @"Example.sqlite";
    
    //Create object store
    objectManager.objectStore = [RKManagedObjectStore objectStoreWithStoreFilename:databaseName 
                                                             usingSeedDatabaseName:seedDatabaseName 
                                                                managedObjectModel:nil delegate:self];

    // Globally use JSON as the wire format for POST/PUT operations
    objectManager.serializationMIMEType = RKMIMETypeJSON;
    
    // Construct our own NSDateFormatter
    NSDateFormatter *dateFormatter = [NSDateFormatter new];
    [dateFormatter  setDateFormat:@"yyyy-MM-dd"];
    
    [RKObjectMapping addDefaultDateFormatter:dateFormatter];

    RKManagedObjectMapping* mapping = [RKManagedObjectMapping mappingForEntityWithName:@"Report" inManagedObjectStore:[RKManagedObjectStore defaultObjectStore]];
    mapping.primaryKeyAttribute = @"guid";
    [mapping mapAttributes:@"guid", @"desc", @"title", @"followed", nil];
    [mapping mapKeyPath:@"created_at" toAttribute:@"createdAt"];
    [mapping mapKeyPath:@"updated_at" toAttribute:@"updatedAt"];
    [mapping mapKeyPath:@"photo_url" toAttribute:@"imageURL"];
    
    // Register our mappings with the provider
    [objectManager.mappingProvider setMapping:mapping forKeyPath:@"reports"];
    [objectManager.mappingProvider setMapping:mapping forKeyPath:@"report"];

    self.window = [[UIWindow alloc] initWithFrame:[[UIScreen mainScreen] bounds]];
    // Override point for customization after application launch.
    LocalViewController *viewController1 = [[LocalViewController alloc] initWithStyle:UITableViewStylePlain];
    RemoteViewController *viewController2 = [[RemoteViewController alloc] initWithStyle:UITableViewStylePlain];

    self.tabBarController = [[UITabBarController alloc] init];
    self.tabBarController.viewControllers = [NSArray arrayWithObjects:viewController1, viewController2, nil];
    self.window.rootViewController = self.tabBarController;
    [self.window makeKeyAndVisible];
    
    return YES;
}

@end
